==> tabular-data-commons-2.0.0-20140225.145837-26-sources.jar: org/gcube/data/analysis/tabulardata/commons/templates/model/Template.java <==
package org.gcube.data.analysis.tabulardata.commons.templates.model;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import org.gcube.common.validator.annotations.NotEmpty;
import org.gcube.common.validator.annotations.NotNull;
import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.FinalAction;
import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.TemplateColumn;
import org.gcube.data.analysis.tabulardata.commons.webservice.types.OnRowErrorAction;



@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class Template {


	
	@NotEmpty
	private List<TemplateColumn<?>> columns;
	
	@NotNull
	private OnRowErrorAction onRowErrorAction = OnRowErrorAction.ASK;
	
	@NotNull
	private List<TemplateAction<Long>> actions = new ArrayList<TemplateAction<Long>>(); 
	
	@NotNull
	private FinalAction finalAction = FinalAction.NONE;
	
	private TemplateCategory category;
	
	public static Template create(TemplateCategory templateType, TemplateColumn<?> ... columns ){
		return new Template(templateType, columns);
	}
	
	private Template(){}
	
	private Template(TemplateCategory templateType ,TemplateColumn<?>[] columns){
		for (TemplateColumn<?> column: columns)
			if (!templateType.getAllowedColumn().contains(column.getColumnType()))
				throw new IllegalArgumentException(String.format("column type %s not allowed for template type %s ",column.getColumnType().name(), templateType.name()));
		this.columns = Arrays.asList(columns);		
		this.category = templateType;
	}

	/**
	 * @return the columns
	 */
	public List<TemplateColumn<?>> getColumns() {
		return columns;
	}

	/**
	 * @param columns the columns to set
	 */
	public void setColumns(List<TemplateColumn<?>> columns) {
		this.columns = columns;
	}

	/**
	 * @return the onErrorAction
	 */
	public OnRowErrorAction getOnRowErrorAction() {
		return onRowErrorAction;
	}

	/**
	 * @param onErrorAction the onErrorAction to set
	 */
	public void setOnErrorAction(OnRowErrorAction onErrorAction) {
		this.onRowErrorAction = onErrorAction;
	}

	/**
	 * @return the operations
	 */
	public List<TemplateAction<Long>> getActions() {
		return actions;
	}

	/**
	 * @param operations the operations to set
	 */
	public void setActions(List<TemplateAction<Long>> actions) {
		this.actions = actions;
	}

	/**
	 * @return the finalAction
	 */
	public FinalAction getFinalAction() {
		return finalAction;
	}

	/**
	 * @param finalAction the finalAction to set
	 */
	public void setFinalAction(FinalAction finalAction) {
		this.finalAction = finalAction;
	}
	
	
	/**
	 * @return the category
	 */
	public TemplateCategory getCategory() {
		return category;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "Template [columns=" + columns + ", onErrorAction=" + onRowErrorAction + ", actions="
				+ actions + ", finalAction=" + finalAction + "]";
	}
	
}

==> tabular-data-commons-2.2.0-20140701.165959-13-sources.jar: org/gcube/data/analysis/tabulardata/commons/templates/model/Template.java <==
package org.gcube.data.analysis.tabulardata.commons.templates.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.common.validator.annotations.NotEmpty;
import org.gcube.common.validator.annotations.NotNull;
import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.FinalAction;
import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.ColumnCategory;
import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.ColumnDescription;
import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.TemplateColumn;
import org.gcube.data.analysis.tabulardata.commons.webservice.types.OnRowErrorAction;



@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class Template implements Serializable{

	
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@NotEmpty
	private List<TemplateColumn<?>> columns;
	
	@NotNull
	private OnRowErrorAction onRowErrorAction = OnRowErrorAction.ASK;
	
	@NotNull
	private List<TemplateAction<Long>> actions = new ArrayList<TemplateAction<Long>>(); 
	
	@NotNull
	private FinalAction finalAction = FinalAction.NONE;
	
	private TemplateCategory category;
	
	public static Template create(TemplateCategory templateType, TemplateColumn<?> ... columns ){
		return new Template(templateType, columns);
	}
	
	private Template(){}
	
	private Template(TemplateCategory templateType ,TemplateColumn<?>[] columns){
		for (TemplateColumn<?> column: columns)
			if (!containsColumnCategory(templateType.getAllowedColumn(), column.getColumnType()))
				throw new IllegalArgumentException(String.format("column type %s not allowed for template type %s ",column.getColumnType().name(), templateType.name()));
		this.columns = Arrays.asList(columns);		
		this.category = templateType;
	}

	private static boolean containsColumnCategory(List<ColumnDescription> allowedColumns, ColumnCategory columnType){
		for (ColumnDescription desc: allowedColumns)
			if (desc.getColumnCategory()==columnType) return true;
		return false;
	}

	/**
	 * @return the columns
	 */
	public List<TemplateColumn<?>> getColumns() {
		return columns;
	}

	/**
	 * @param columns the columns to set
	 */
	public void setColumns(List<TemplateColumn<?>> columns) {
		this.columns = columns;
	}

	/**
	 * @return the onErrorAction
	 */
	public OnRowErrorAction getOnRowErrorAction() {
		return onRowErrorAction;
	}

	/**
	 * @param onErrorAction the onErrorAction to set
	 */
	public void setOnErrorAction(OnRowErrorAction onErrorAction) {
		this.onRowErrorAction = onErrorAction;
	}

	/**
	 * @return the operations
	 */
	public List<TemplateAction<Long>> getActions() {
		return actions;
	}

	/**
	 * @param operations the operations to set
	 */
	public void setActions(List<TemplateAction<Long>> actions) {
		this.actions = actions;
	}

	/**
	 * @return the finalAction
	 */
	public FinalAction getFinalAction() {
		return finalAction;
	}

	/**
	 * @param finalAction the finalAction to set
	 */
	public void setFinalAction(FinalAction finalAction) {
		this.finalAction = finalAction;
	}
	
	
	/**
	 * @return the category
	 */
	public TemplateCategory getCategory() {
		return category;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "Template [columns=" + columns + ", onErrorAction=" + onRowErrorAction + ", actions="
				+ actions + ", finalAction=" + finalAction + "]";
	}
	
}
